#! /bin/bash

# set path on execution
TARGET=$(dirname "$(realpath $0)")
cd $TARGET


if [ -e hugo.toml ]
then
  echo "you are in the wrong directory"
  exit 1
fi

if [ -z "$1" ]
then
  echo "missing Parameter URL"
  echo "usage:"
  echo "sh url_replacer <new_url>"
  exit 1
fi

find . -type f -name '*.html' -exec sed -i "s/URL/$1/g" {} +
find . -type f -name '*.xml' -exec sed -i "s/URL/$1/g" {} +

